.. include:: ../README.rst

.. toctree::
   :caption: Welcome
   :maxdepth: 1

   Welcome/Installations
   Welcome/GettingStarted
   Welcome/FrequentQuestions
   Welcome/Changelog


.. toctree::
   :caption: C++ API
   :maxdepth: 1

   generated_api/index


Indices and tables
~~~~~~~~~~~~~~~~~~

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
